@@ -473,7 +473,7 @@ print("<h1>登録情報変更</h1>");
 </form>
 <?php
 //----------------------------device edit mode end-------------
-} else if ( 0 == strcmp( "0",  $_var["mode"] ) ) {  
+} else if ( ( 0 == strcmp( "ACTION",  $_var["mode"] )) && ( 0 == $org["flags"] ) ) {  
 //----------------------------new device found mode -----------------
 print("<h1>このUSBデバイス(".$org["nickname"].")は未登録です</h1>");
 
@@ -540,9 +540,9 @@ $flags = $org["flags"];
   if (   4 == (    4 & $flags )) {
 //----------------------------actionconfirm mode start-------------
 
-    print("<h1>このUSBデバイスは".$actions."として設定されています</h1>");
+    print("<h1>".$actions."を行います</h1>");
 ?>
- <b>以下のボタンを押して開始してください</b>
+ <b>画面の切替に時間がかかる場合がありますがお待ちください</b>
  <form action="regist.php" method="POST">
  <input type="submit">
  <input type="hidden" name="devname" value="<?php echo $_var["devname"]; ?>">
@@ -593,7 +593,7 @@ $flags = $org["flags"];
 } else if ( 0 == strcmp("DOACTION", $_var["mode"])){
 //----------------------------manual action mode start --------------------
   	
-ob_end_flush();
+ flush(); ob_end_flush();ob_start();
 
 $flags = $org["flags"];
   $actions="";
@@ -609,9 +609,10 @@ $flags = $org["flags"];
   if ( 512 == (  512 & $flags )) { $actions = $actions."「持出可」"; }
 
   if (   4 == (    4 & $flags )) {
-//----------------------------actionconfirm mode start-------------
+//----------------------------DOACTION mode start-------------
 
-    print("<h1>このUSBデバイスは".$actions."として設定されています</h1>");
+    print("<h1>".$actions."を処理しています</h1>");
+  flush(); ob_end_flush(); ob_start();
   if (        1 == (    1 & $flags )) {
      $action = "「使用禁止」"; 
      print $action;
@@ -619,13 +620,16 @@ $flags = $org["flags"];
   if (  16 == (   16 & $flags )) {
       $action = "「実行ファイル削除」";
       print $action;
-      print "<h1>消毒中...</h1>";
+      passthru("date");
+      printf ("<h1>消毒中...</h1>\n");
+      flush();ob_end_flush(); ob_start();
+      printf ("                                                                                        \n"); // buffer flusher
+      flush();ob_end_flush(); ob_start();
       print "<pre>";
       print $_var["devname"]."\n";
+      passthru("sleep 10");
       passthru("sudo mount ".$_var["devname"]." /mnt".$_var["devname"]);
-      //passthru("sudo mount");
-      //print "-------------\n";
-      passthru("sudo usbsearchdelete /mnt".$_var["devname"]);
+      passthru("sudo time usbsearchdelete /mnt".$_var["devname"]);
       passthru("sudo umount ".$_var["devname"]);
       print "</pre>";
   }
@@ -633,22 +637,39 @@ $flags = $org["flags"];
       $action = "「検疫済ファイルを外部にコピー」";
       print $action;
       print "<h1>外部にコピー中...</h1>";
+      printf ("                                                                                        \n"); // buffer flusher
+      flush(); ob_end_flush(); ob_start();
       print "<pre>";
       passthru("sudo mkdir -p /mnt".$_var["devname"]);
       passthru("sudo mount ".$_var["devname"]." /mnt".$_var["devname"]);
-      passthru("sudo smbmount ".$_var["distpath"]." /mnt/$id -o username=".$_var["distaccount"]);
-      passthru("sudo cp -a /mnt".$_var["devname"]."/ /mnt/".$_var["id"]);
+ //     echo("############".$org["distaccount"]."\n");
+ //     echo("############".$org["distpath"]."\n");
+ //     echo("sudo smbmount ".$org["distpath"]." /mnt/".$_var["id"]." -o username=".$org["distaccount"]);
+      passthru("sudo smbmount ".$org["distpath"]." /mnt/".$_var["id"]." -o username=".$org["distaccount"]);
+      $nowstring = date("Ymd-His");
+      passthru("sudo mkdir -p /mnt/".$_var["id"]."/".$nowstring);
+      echo("sudo cp -a /mnt".$_var["devname"]."/ /mnt/".$_var["id"]."/".$nowstring);
+      passthru("sudo cp -a /mnt".$_var["devname"]."/ /mnt/".$_var["id"]."/".$nowstring);
+      echo("sudo umount ".$_var["devname"]);
       passthru("sudo umount ".$_var["devname"]);
+      echo("sudo umount  /mnt/".$_var["id"]);
+      passthru("sudo umount  /mnt/".$_Var["id"]);
       print "</pre>";
   }
   if (  64 == (   64 & $flags )) {
       $action = "「フォーマット」";
       print $action;
       print "<h1>format中...</h1>";
+      printf ("                                                                                        \n"); // buffer flusher
+      flush(); ob_end_flush(); ob_start();
       print "<pre>";
+      printf ("start ");
+      passthru("date");
       passthru("sudo mkfs.vfat   ".$_var["devname"]);
+      printf ("end   ");
+      passthru("date");
       passthru("sudo mount ".$_var["devname"]." /var/squarantine/usbstorages/".$org["nickname"]);
-      passthru("echo sudo mount ".$_var["devname"]." /var/squarantine/usbstorages/".$org["nickname"]);
+      # passthru("echo sudo mount ".$_var["devname"]." /var/squarantine/usbstorages/".$org["nickname"]);
       #passthru("find /etc -name a*");
       print "</pre>";
   }
@@ -659,14 +680,17 @@ $flags = $org["flags"];
     if ( 256 == (  256 & $flags )) {
        $action = "「検疫後共有公開」";
        print $action;
-       if ( 512 == (  512 & $flags )) {
+       flush(); ob_end_flush(); ob_start();
+        if ( 512 == (  512 & $flags )) {
           $action = "「持出可」";
           print $action;
+          flush(); ob_end_flush(); ob_start();
           passthru("sudo mount ".$_var["devname"]." /var/squarantine/usbstorages/".$org["nickname"]);
        } else {
           passthru("sudo mount -r ".$_var["devname"]." /var/squarantine/usbstorages/".$org["nickname"]);
        }
        print "<h2>終了しました</h2>";
+      passthru("date");
        print "<a href=\"file:".$conf["SAMBAPATH"]."\">こちらからアクセスしてください</a>";
 
     }
